package javax.swing.plaf.nimbus;

import java.awt.Component;
import javax.swing.JComponent;
import java.awt.image.BufferedImage;
import java.awt.Graphics2D;
import javax.swing.plaf.UIResource;
import javax.swing.JMenu;
import javax.swing.JToolBar;
import javax.swing.UIManager;
import javax.swing.Painter;
import java.awt.Graphics;
import javax.swing.plaf.synth.SynthContext;
import sun.swing.plaf.synth.SynthIcon;

class NimbusIcon extends SynthIcon
{
    private int width;
    private int height;
    private String prefix;
    private String key;
    
    NimbusIcon(String prefix, String key, int width, int height) {
        this.width = width;
        this.height = height;
        this.prefix = prefix;
        this.key = key;
    }
    
    public void paintIcon(SynthContext context, Graphics graphics, int n, int n2, int width, int height) {
        Painter painter = null;
        if (context != null) {
            painter = (Painter)context.getStyle().get(context, this.key);
        }
        if (painter == null) {
            painter = (Painter)UIManager.get(this.prefix + "[Enabled]." + this.key);
        }
        if (painter != null && context != null) {
            JComponent component = context.getComponent();
            int n3 = 0;
            int n4 = 0;
            int n5 = 0;
            int n6 = 0;
            if ((component instanceof JToolBar)) {
                JToolBar toolBar = (JToolBar)component;
                n3 = (toolBar.getOrientation() == 1);
                n4 = (toolBar.getComponentOrientation().isLeftToRight() ? false : true);
                Object resolveToolbarConstraint = NimbusLookAndFeel.resolveToolbarConstraint(toolBar);
                if ((toolBar.getBorder() instanceof UIResource)) {
                    if (resolveToolbarConstraint == "South") {
                        n6 = 1;
                    }
                    else if (resolveToolbarConstraint == "East") {
                        n5 = 1;
                    }
                }
            }
            else if ((component instanceof JMenu)) {
                n4 = (component.getComponentOrientation().isLeftToRight() ? 0 : 1);
            }
            if ((graphics instanceof Graphics2D)) {
                Graphics2D graphics2D = (Graphics2D)graphics;
                graphics2D.translate(n, n2);
                graphics2D.translate(n5, n6);
                if (n3 != 0) {
                    graphics2D.rotate(Math.toRadians(90.0));
                    graphics2D.translate(0, -width);
                    painter.paint(graphics2D, context.getComponent(), height, width);
                    graphics2D.translate(0, width);
                    graphics2D.rotate(Math.toRadians(-90.0));
                }
                else if (n4 != 0) {
                    graphics2D.scale(-1.0, 1.0);
                    graphics2D.translate(-width, 0);
                    painter.paint(graphics2D, context.getComponent(), width, height);
                    graphics2D.translate(width, 0);
                    graphics2D.scale(-1.0, 1.0);
                }
                else {
                    painter.paint(graphics2D, context.getComponent(), width, height);
                }
                graphics2D.translate(-n5, -n6);
                graphics2D.translate(-n, -n2);
            }
            else {
                BufferedImage o = new BufferedImage(width, height, 2);
                Graphics2D graphics2 = o.createGraphics();
                if (n3 != 0) {
                    graphics2.rotate(Math.toRadians(90.0));
                    graphics2.translate(0, -width);
                    painter.paint(graphics2, context.getComponent(), height, width);
                }
                else if (n4 != 0) {
                    graphics2.scale(-1.0, 1.0);
                    graphics2.translate(-width, 0);
                    painter.paint(graphics2, context.getComponent(), width, height);
                }
                else {
                    painter.paint(graphics2, context.getComponent(), width, height);
                }
                graphics2.dispose();
                graphics.drawImage(o, n, n2, null);
            }
        }
    }
    
    public void paintIcon(Component component, Graphics graphics, int n, int n2) {
        Painter painter = (Painter)UIManager.get(this.prefix + "[Enabled]." + this.key);
        if (painter != null) {
            JComponent component2 = (component instanceof JComponent) ? ((JComponent)component) : null;
            Graphics2D graphics2D = (Graphics2D)graphics;
            graphics2D.translate(n, n2);
            painter.paint(graphics2D, component2, this.width, this.height);
            graphics2D.translate(-n, -n2);
        }
    }
    
    public int getIconWidth(SynthContext synthContext) {
        if (synthContext == null) {
            return this.width;
        }
        JComponent component = synthContext.getComponent();
        if (component instanceof JToolBar && ((JToolBar)component).getOrientation() == 1) {
            if ((component.getBorder() instanceof UIResource)) {
                return component.getWidth() - 1;
            }
            return component.getWidth();
        }
        else {
            return this.scale(synthContext, this.width);
        }
    }
    
    public int getIconHeight(SynthContext synthContext) {
        if (synthContext == null) {
            return this.height;
        }
        JComponent component = synthContext.getComponent();
        if ((component instanceof JToolBar)) {
            JToolBar toolBar = (JToolBar)component;
            if (toolBar.getOrientation() == 0) {
                if ((toolBar.getBorder() instanceof UIResource)) {
                    return component.getHeight() - 1;
                }
                return component.getHeight();
            }
            else {
                return this.scale(synthContext, this.width);
            }
        }
        else {
            return this.scale(synthContext, this.height);
        }
    }
    
    private int scale(SynthContext synthContext, int n) {
        if (synthContext == null || synthContext.getComponent() == null) {
            return n;
        }
        String anObject = (String)synthContext.getComponent().getClientProperty("JComponent.sizeVariant");
        if (anObject != null) {
            if ("large".equals(anObject)) {
                n = (int)((double)n * 1.15);
            }
            else if ("small".equals(anObject)) {
                n = (int)((double)n * 0.857);
            }
            else if ("mini".equals(anObject)) {
                n = (int)((double)n * 0.784);
            }
        }
        return n;
    }
}
